@@ -210,19 +210,6 @@ add_subaction(ThunarxMenuItem *item, ThunarxMenu *menu, const gchar *name, const
 }
 
 
-static void
-add_subaction_u (ThunarxMenu *menu, const gchar *name, const gchar *text, const gchar *tooltip, const gchar *icon, gchar *arg)
-{
-    /* keep the current behavior, only show menu items if they are implemented  */
-    /*ThunarxMenuItem *subitem;
-    subitem = thunarx_menu_item_new (name, text, tooltip, icon);
-    thunarx_menu_append_item (menu, subitem);
-    g_object_set_qdata (G_OBJECT (subitem), tvp_action_arg_quark, arg);
-    g_signal_connect_after (subitem, "activate", G_CALLBACK (tvp_action_unimplemented), arg);
-    g_object_unref (subitem);*/
-}
-
-
 static void
 tvp_git_action_create_menu_item (ThunarxMenuItem *item)
 {
@@ -232,36 +219,36 @@ tvp_git_action_create_menu_item (ThunarxMenuItem *item)
     menu = thunarx_menu_new ();
     thunarx_menu_item_set_menu (item, menu);
 
-    add_subaction (item, menu, "tvp::git::add", Q_("Menu|Add"), _("Add"), "list-add", "--add");
-    add_subaction_u(menu, "tvp::git::bisect", Q_("Menu|Bisect"), _("Bisect"), NULL, _("Bisect"));
+    add_subaction (item, menu, "tvp::git::add", _("Add"), _("Add file contents to the index"), "list-add", "--add");
+    /* unimplemented: add_subaction(item, menu, "tvp::git::bisect", _("Bisect"), _("Bisect"), NULL, _("Bisect"));*/
     if (tvp_action->property.is_file)
-        add_subaction (item, menu, "tvp::git::blame", Q_("Menu|Blame"), _("Blame"), "gtk-index", "--blame");
+        add_subaction (item, menu, "tvp::git::blame", _("Blame"), _("Show what revision and author last modified each line of a file"), "gtk-index", "--blame");
     if (tvp_action->property.is_parent)
-        add_subaction (item, menu, "tvp::git::branch", Q_("Menu|Branch"), _("Branch"), NULL, "--branch");
-    add_subaction_u(menu, "tvp::git::checkout", Q_("Menu|Checkout"), _("Checkout"), "gtk-connect", _("Checkout"));
-    add_subaction (item, menu, "tvp::git::clean", Q_("Menu|Clean"), _("Clean"), "edit-clear", "--clean");
+        add_subaction (item, menu, "tvp::git::branch", _("Branch"), _("List, create or switch branches"), "media-playlist-shuffle", "--branch");
+    /* unimplemented: add_subaction(item, menu, "tvp::git::checkout", _("Checkout"), _("Checkout"), "gtk-connect", _("Checkout"));*/
+    add_subaction (item, menu, "tvp::git::clean", _("Clean"), _("Remove untracked files from the working tree"), "edit-clear", "--clean");
     if (tvp_action->property.is_parent)
-        add_subaction (item, menu, "tvp::git::clone", Q_("Menu|Clone"), _("Clone"), "edit-copy", "--clone");
-    add_subaction_u(menu, "tvp::git::commit", Q_("Menu|Commit"), _("Commit"), "gtk-apply", _("Commit"));
-    add_subaction_u(menu, "tvp::git::diff", Q_("Menu|Diff"), _("Diff"), "edit-find-replace", _("Diff"));
-    add_subaction_u(menu, "tvp::git::fetch", Q_("Menu|Fetch"), _("Fetch"), NULL, _("Fetch"));
-    add_subaction_u(menu, "tvp::git::grep", Q_("Menu|Grep"), _("Grep"), NULL, _("Grep"));
-    add_subaction_u(menu, "tvp::git::init", Q_("Menu|Init"), _("Init"), NULL, _("Init"));
-    add_subaction (item, menu, "tvp::git::log", Q_("Menu|Log"), _("Log"), "gtk-index", "--log");
-    add_subaction_u(menu, "tvp::git::merge", Q_("Menu|Merge"), _("Merge"), NULL, _("Merge"));
+        add_subaction (item, menu, "tvp::git::clone", _("Clone"), _("Clone a repository into a new directory"), "edit-copy", "--clone");
+    /* unimplemented: add_subaction(item, menu, "tvp::git::commit", _("Commit"), _("Commit"), "gtk-apply", _("Commit"));*/
+    /* unimplemented: add_subaction(item, menu, "tvp::git::diff", _("Diff"), _("Diff"), "edit-find-replace", _("Diff"));*/
+    /* unimplemented: add_subaction(item, menu, "tvp::git::fetch", _("Fetch"), _("Fetch"), NULL, _("Fetch"));*/
+    /* unimplemented: add_subaction(item, menu, "tvp::git::grep", _("Grep"), _("Grep"), NULL, _("Grep"));*/
+    /* unimplemented: add_subaction(item, menu, "tvp::git::init", _("Init"), _("Init"), NULL, _("Init"));*/
+    add_subaction (item, menu, "tvp::git::log", _("Log"), _("Show commit logs"), "gtk-index", "--log");
+    /* unimplemented: add_subaction(item, menu, "tvp::git::merge", _("Merge"), _("Merge"), NULL, _("Merge"));*/
     if (!tvp_action->property.is_parent)
-        add_subaction (item, menu, "tvp::git::move", Q_("Menu|Move"), _("Move"), "gtk-dnd-multiple", "--move");
-    add_subaction_u(menu, "tvp::git::pull", Q_("Menu|Pull"), _("Pull"), NULL, _("Pull"));
-    add_subaction_u(menu, "tvp::git::push", Q_("Menu|Push"), _("Push"), NULL, _("Push"));
-    add_subaction_u(menu, "tvp::git::rebase", Q_("Menu|Rebase"), _("Rebase"), NULL, _("Rebase"));
-    add_subaction (item, menu, "tvp::git::reset", Q_("Menu|Reset"), _("Reset"), "edit-undo", "--reset");
-    add_subaction_u(menu, "tvp::git::remove", Q_("Menu|Remove"), _("Remove"), "edit-delete", _("Remove"));
-    add_subaction_u(menu, "tvp::git::show", Q_("Menu|Show"), _("Show"), NULL, _("Show"));
+        add_subaction (item, menu, "tvp::git::move", _("Move"), _("Move or rename a file, a directory, or a symlink"), "gtk-dnd-multiple", "--move");
+    /* unimplemented: add_subaction(item, menu, "tvp::git::pull", _("Pull"), _("Pull"), NULL, _("Pull"));*/
+    /* unimplemented: add_subaction(item, menu, "tvp::git::push", _("Push"), _("Push"), NULL, _("Push"));*/
+    /* unimplemented: add_subaction(item, menu, "tvp::git::rebase", _("Rebase"), _("Rebase"), NULL, _("Rebase"));*/
+    add_subaction (item, menu, "tvp::git::reset", _("Reset"), _("Reset current HEAD to the specified state"), "edit-undo", "--reset");
+    /* unimplemented: add_subaction(item, menu, "tvp::git::remove", _("Remove"), _("Remove"), "edit-delete", _("Remove"));*/
+    /* unimplemented: add_subaction(item, menu, "tvp::git::show", _("Show"), _("Show"), NULL, _("Show"));*/
     if (tvp_action->property.is_parent)
-        add_subaction (item, menu, "tvp::git::stash", Q_("Menu|Stash"), _("Stash"), "document-save", "--stash");
+        add_subaction (item, menu, "tvp::git::stash", _("Stash"), _("Stash the changes in a dirty working directory away"), "document-save", "--stash");
     if (tvp_action->property.is_parent)
-        add_subaction (item, menu, "tvp::git::status", Q_("Menu|Status"), _("Status"), "dialog-information", "--status");
-    add_subaction_u(menu, "tvp::git::tag", Q_("Menu|Tag"), _("Tag"), NULL, _("Tag"));
+        add_subaction (item, menu, "tvp::git::status", _("Status"), _("Show the working tree status"), "dialog-information", "--status");
+    /* unimplemented: add_subaction(item, menu, "tvp::git::tag", _("Tag"), _("Tag"), NULL, _("Tag"));*/
 }
 
 
