@@ -55,21 +55,21 @@
 
 
 
-static void   tvp_provider_menu_provider_init   (ThunarxMenuProviderIface *iface);
+static void   tvp_provider_menu_provider_init          (ThunarxMenuProviderIface *iface);
 static void   tvp_provider_property_page_provider_init (ThunarxPropertyPageProviderIface *iface);
-static void   tvp_provider_finalize             (GObject                  *object);
-static GList *tvp_provider_get_file_actions     (ThunarxMenuProvider      *menu_provider,
-                                                 GtkWidget                *window,
-                                                 GList                    *files);
-static GList *tvp_provider_get_folder_actions   (ThunarxMenuProvider      *menu_provider,
-                                                 GtkWidget                *window,
-                                                 ThunarxFileInfo          *folder);
-static GList *tvp_provider_get_pages            (ThunarxPropertyPageProvider *menu_provider,
-                                                 GList                    *files);
-static void   tvp_new_process                   (GtkAction                *action,
-                                                 const GPid               *pid,
-                                                 const gchar              *path,
-                                                 TvpProvider              *tvp_provider);
+static void   tvp_provider_finalize                    (GObject                  *object);
+static GList *tvp_provider_get_file_menu_items         (ThunarxMenuProvider      *menu_provider,
+                                                        GtkWidget                *window,
+                                                        GList                    *files);
+static GList *tvp_provider_get_folder_menu_items       (ThunarxMenuProvider      *menu_provider,
+                                                        GtkWidget                *window,
+                                                        ThunarxFileInfo          *folder);
+static GList *tvp_provider_get_pages                   (ThunarxPropertyPageProvider *menu_provider,
+                                                        GList                    *files);
+static void   tvp_new_process                          (ThunarxMenuItem          *item,
+                                                        const GPid               *pid,
+                                                        const gchar              *path,
+                                                        TvpProvider              *tvp_provider);
 
 
 
@@ -91,22 +91,10 @@ struct _TvpProvider
   GObject __parent__;
 
   TvpChildWatch *child_watch;
-
-#if !GTK_CHECK_VERSION(2,9,0)
-  /* GTK+ 2.9.0 and above provide an icon-name property
-   * for GtkActions, so we don't need the icon factory.
-   */
-  GtkIconFactory *icon_factory;
-#endif
 };
 
 
 
-//static GQuark tvp_action_files_quark;
-//static GQuark tvp_action_provider_quark;
-
-
-
 THUNARX_DEFINE_TYPE_WITH_CODE (TvpProvider,
                                tvp_provider,
                                G_TYPE_OBJECT,
@@ -121,10 +109,6 @@ tvp_provider_class_init (TvpProviderClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the "tvp-action-files", "tvp-action-folder" and "tvp-action-provider" quarks */
-  //tvp_action_files_quark = g_quark_from_string ("tvp-action-files");
-  //tvp_action_provider_quark = g_quark_from_string ("tvp-action-provider");
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = tvp_provider_finalize;
 }
@@ -134,8 +118,8 @@ tvp_provider_class_init (TvpProviderClass *klass)
 static void
 tvp_provider_menu_provider_init (ThunarxMenuProviderIface *iface)
 {
-  iface->get_file_actions = tvp_provider_get_file_actions;
-  iface->get_folder_actions = tvp_provider_get_folder_actions;
+  iface->get_file_menu_items = tvp_provider_get_file_menu_items;
+  iface->get_folder_menu_items = tvp_provider_get_folder_menu_items;
 }
 
 
@@ -151,24 +135,6 @@ tvp_provider_property_page_provider_init (ThunarxPropertyPageProviderIface *ifac
 static void
 tvp_provider_init (TvpProvider *tvp_provider)
 {
-#if !GTK_CHECK_VERSION(2,9,0)
-  GtkIconSource *icon_source;
-  GtkIconSet *icon_set;
-
-  /* setup our icon factory */
-  tvp_provider->icon_factory = gtk_icon_factory_new ();
-  gtk_icon_factory_add_default (tvp_provider->icon_factory);
-
-  /* add the "subversion" stock icon */
-  icon_set = gtk_icon_set_new ();
-  icon_source = gtk_icon_source_new ();
-  gtk_icon_source_set_icon_name (icon_source, "subversion");
-  gtk_icon_set_add_source (icon_set, icon_source);
-  gtk_icon_factory_add (tvp_provider->icon_factory, "subversion", icon_set);
-  gtk_icon_source_free (icon_source);
-  gtk_icon_set_unref (icon_set);
-#endif /* !GTK_CHECK_VERSION(2,9,0) */
-
 #ifdef HAVE_SUBVERSION
   tvp_svn_backend_init();
 #endif
@@ -187,17 +153,10 @@ tvp_provider_finalize (GObject *object)
     g_source_set_callback (source, (GSourceFunc) g_spawn_close_pid, NULL, NULL);
   }
 
-#if !GTK_CHECK_VERSION(2,9,0)
-  /* release our icon factory */
-  gtk_icon_factory_remove_default (tvp_provider->icon_factory);
-  g_object_unref (G_OBJECT (tvp_provider->icon_factory));
-#endif
-
 #ifdef HAVE_SUBVERSION
   tvp_svn_backend_free();
 #endif
 
-
   (*G_OBJECT_CLASS (tvp_provider_parent_class)->finalize) (object);
 }
 
@@ -381,12 +340,12 @@ tvp_compare_path (TvpSvnFileStatus *file_status, ThunarxFileInfo *file_info)
 
 
 static GList*
-tvp_provider_get_file_actions (ThunarxMenuProvider *menu_provider,
-                               GtkWidget           *window,
-                               GList               *files)
+tvp_provider_get_file_menu_items (ThunarxMenuProvider *menu_provider,
+                                  GtkWidget           *window,
+                                  GList               *files)
 {
-  GList              *actions = NULL;
-  GtkAction          *action;
+  GList              *items = NULL;
+  ThunarxMenuItem    *item;
   GList              *lp;
   gint               n_files = 0;
   gchar              *scheme;
@@ -430,12 +389,10 @@ tvp_provider_get_file_actions (ThunarxMenuProvider *menu_provider,
       if (tvp_is_working_copy (lp->data))
       {
         directory_is_wc = TRUE;
-        //g_object_set_data(lp->data, TVP_SVN_WORKING_COPY, GINT_TO_POINTER(TRUE));
       }
       else
       {
         directory_is_not_wc = TRUE;
-        //g_object_set_data(lp->data, TVP_SVN_WORKING_COPY, GINT_TO_POINTER(FALSE));
       }
     }
     else
@@ -460,10 +417,10 @@ tvp_provider_get_file_actions (ThunarxMenuProvider *menu_provider,
     }
   }
 
-  /* append the svn submenu action */
-  action = tvp_svn_action_new ("Tvp::svn", _("SVN"), files, window, FALSE, parent_wc, directory_is_wc, directory_is_not_wc, file_is_vc, file_is_not_vc);
-  g_signal_connect(action, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
-  actions = g_list_append (actions, action);
+  /* append the svn submenu item */
+  item = tvp_svn_action_new ("Tvp::svn", _("SVN"), files, window, FALSE, parent_wc, directory_is_wc, directory_is_not_wc, file_is_vc, file_is_not_vc);
+  g_signal_connect(item, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
+  items = g_list_append (items, item);
 #endif
 
 #ifdef HAVE_GIT
@@ -491,24 +448,24 @@ tvp_provider_get_file_actions (ThunarxMenuProvider *menu_provider,
     }
   }
 
-  /* append the git submenu action */
-  action = tvp_git_action_new ("Tvp::git", _("GIT"), files, window, FALSE, directory, file);
-  g_signal_connect(action, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
-  actions = g_list_append (actions, action);
+  /* append the git submenu item */
+  item = tvp_git_action_new ("Tvp::git", _("GIT"), files, window, FALSE, directory, file);
+  g_signal_connect(item, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
+  items = g_list_append (items, item);
 #endif
 
-  return actions;
+  return items;
 }
 
 
 
 static GList*
-tvp_provider_get_folder_actions (ThunarxMenuProvider *menu_provider,
-                                 GtkWidget           *window,
-                                 ThunarxFileInfo     *folder)
+tvp_provider_get_folder_menu_items (ThunarxMenuProvider *menu_provider,
+                                    GtkWidget           *window,
+                                    ThunarxFileInfo     *folder)
 {
-  GtkAction          *action;
-  GList              *actions = NULL;
+  ThunarxMenuItem    *item;
+  GList              *items = NULL;
   gchar              *scheme;
   GList              *files;
 
@@ -527,22 +484,22 @@ tvp_provider_get_folder_actions (ThunarxMenuProvider *menu_provider,
 
 #ifdef HAVE_SUBVERSION
   /* Lets see if we are dealing with a working copy */
-  action = tvp_svn_action_new ("Tvp::svn", _("SVN"), files, window, TRUE, tvp_is_working_copy (folder), FALSE, FALSE, FALSE, FALSE);
-  g_signal_connect(action, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
-  /* append the svn submenu action */
-  actions = g_list_append (actions, action);
+  item = tvp_svn_action_new ("Tvp::svn", _("SVN"), files, window, TRUE, tvp_is_working_copy (folder), FALSE, FALSE, FALSE, FALSE);
+  g_signal_connect(item, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
+  /* append the svn submenu item */
+  items = g_list_append (items, item);
 #endif
 
 #ifdef HAVE_GIT
-  action = tvp_git_action_new ("Tvp::git", _("GIT"), files, window, TRUE, TRUE, FALSE);
-  g_signal_connect(action, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
-  /* append the git submenu action */
-  actions = g_list_append (actions, action);
+  item = tvp_git_action_new ("Tvp::git-folder", _("GIT"), files, window, TRUE, TRUE, FALSE);
+  g_signal_connect(item, "new-process", G_CALLBACK(tvp_new_process), menu_provider);
+  /* append the git submenu item */
+  items = g_list_append (items, item);
 #endif
 
   g_list_free (files);
 
-  return actions;
+  return items;
 }
 
 
@@ -609,30 +566,6 @@ tvp_provider_get_pages (ThunarxPropertyPageProvider *page_provider, GList *files
 static void
 tvp_child_watch (GPid pid, gint status, gpointer data)
 {
-  /*
-  gchar *watch_path = data;
-  ThunarVfsPath *path;
-
-  if (G_LIKELY (data))
-  {
-    GDK_THREADS_ENTER ();
-
-    path = thunar_vfs_path_new (watch_path, NULL);
-
-    if (G_LIKELY (path))
-    {
-      ThunarVfsMonitor *monitor = thunar_vfs_monitor_get_default ();
-      thunar_vfs_monitor_feed (monitor, THUNAR_VFS_MONITOR_EVENT_CHANGED, path);
-      g_object_unref (G_OBJECT (monitor));
-      thunar_vfs_path_unref (path);
-    }
-
-    GDK_THREADS_LEAVE ();
-
-    //this is done by destroy callback
-    //g_free (watch_path);
-  }
-  */
   g_spawn_close_pid (pid);
 }
 
@@ -650,7 +583,7 @@ tvp_child_watch_free (TvpChildWatch *watch)
 
 
 static void
-tvp_new_process (GtkAction *action, const GPid *pid, const gchar *path, TvpProvider *tvp_provider)
+tvp_new_process (ThunarxMenuItem *item, const GPid *pid, const gchar *path, TvpProvider *tvp_provider)
 {
   TvpChildWatch *watch;
   if (tvp_provider->child_watch)
