@@ -245,19 +245,6 @@ add_subaction(ThunarxMenuItem *item, ThunarxMenu *menu, const gchar *name, const
 }
 
 
-static void
-add_subaction_u (ThunarxMenu *menu, const gchar *name, const gchar *text, const gchar *tooltip, const gchar *icon, gchar *arg)
-{
-    /* keep the current behavior, only show menu items if they are implemented  */
-    /*ThunarxMenuItem *subitem;
-    subitem = thunarx_menu_item_new (name, text, tooltip, icon);
-    thunarx_menu_append_item (menu, subitem);
-    g_object_set_qdata (G_OBJECT (subitem), tvp_action_arg_quark, arg);
-    g_signal_connect_after (subitem, "activate", G_CALLBACK (tvp_action_unimplemented), arg);
-    g_object_unref (subitem);*/
-}
-
-
 static void
 tvp_svn_action_create_menu_item (ThunarxMenuItem *item)
 {
@@ -270,12 +257,12 @@ tvp_svn_action_create_menu_item (ThunarxMenuItem *item)
   /* No version control or version control (parent) */
   if (tvp_action->property.parent_version_control && (tvp_action->property.is_parent || tvp_action->property.directory_no_version_control || tvp_action->property.file_no_version_control)) 
   {
-    add_subaction (item, menu, "tvp::add", Q_("Menu|Add"), _("Add"), "list-add", "--add");
+    add_subaction (item, menu, "tvp::add", _("Add"), _("Add files, directories, or symbolic links"), "list-add", "--add");
   }
   /* Version control (file) */
   if (tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::blame", Q_("Menu|Blame"), _("Blame"), "gtk-index", "--blame");
+    add_subaction (item, menu, "tvp::blame", _("Blame"), _("Show what revision and author last modified each line of a file"), "gtk-index", "--blame");
   }
 /* No need
   subitem = gtk_menu_item_new_with_label (_("Cat"));
@@ -287,52 +274,52 @@ tvp_svn_action_create_menu_item (ThunarxMenuItem *item)
 *//* Version control (file) */
   if (tvp_action->property.file_version_control)
   {
-    add_subaction_u (menu, "tvp::changelist", Q_("Menu|Changelist"), _("Changelist"), "gtk-index", _("Changelist"));
+    /* unimplemented: add_subaction_u (menu, "tvp::changelist", _("Changelist"), _("Changelist"), "gtk-index", _("Changelist")); */
   }
   /* No version control (parent) */
   if (tvp_action->property.is_parent && !tvp_action->property.parent_version_control)
   {
-    add_subaction (item, menu, "tvp::checkout", Q_("Menu|Checkout"), _("Checkout"), "gtk-connect", "--checkout");
+    add_subaction (item, menu, "tvp::checkout", _("Checkout"), _("Check out a working copy from a repository"), "gtk-connect", "--checkout");
   }
   /* Version control (parent) */
   if (tvp_action->property.is_parent && tvp_action->property.parent_version_control)
   {
-    add_subaction (item, menu, "tvp::cleanup", Q_("Menu|Cleanup"), _("Cleanup"), "edit-clear", "--cleanup");
+    add_subaction (item, menu, "tvp::cleanup", _("Cleanup"), _("Recursively clean up the working copy"), "edit-clear", "--cleanup");
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::commit", Q_("Menu|Commit"), _("Commit"), "gtk-apply", "--commit");
+    add_subaction (item, menu, "tvp::commit", _("Commit"), _("Send changes from your working copy to the repository"), "gtk-apply", "--commit");
   }
   /* Version control (no parent) */
   if (!tvp_action->property.is_parent && tvp_action->property.parent_version_control && (tvp_action->property.directory_version_control || tvp_action->property.file_version_control))
   {
-    add_subaction (item, menu, "tvp::copy", Q_("Menu|Copy"), _("Copy"), "edit-copy", "--copy");
+    add_subaction (item, menu, "tvp::copy", _("Copy"), _("Copy a file or directory in a working copy or in the repository"), "edit-copy", "--copy");
   }
   /* Version control (no parent) */
   if (!tvp_action->property.is_parent && tvp_action->property.parent_version_control && (tvp_action->property.directory_version_control || tvp_action->property.file_version_control))
   {
-    add_subaction (item, menu, "tvp::delete", Q_("Menu|Delete"), _("Delete"), "edit-delete", "--delete");
+    add_subaction (item, menu, "tvp::delete", _("Delete"), _("Delete an item from a working copy or the repository"), "edit-delete", "--delete");
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::diff", Q_("Menu|Diff"), _("Diff"), "gtk-convert", "--diff");
+    add_subaction (item, menu, "tvp::diff", _("Diff"), _("Display the differences between two revisions or paths"), "gtk-convert", "--diff");
   }
   /* Version control and No version control (parent) */
   if (tvp_action->property.is_parent || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::export", Q_("Menu|Export"), _("Export"), "document-save", "--export");
+    add_subaction (item, menu, "tvp::export", _("Export"), _("Export a clean directory tree"), "document-save", "--export");
   }
   /* No version control (all) */
   if (!tvp_action->property.parent_version_control && (tvp_action->property.is_parent || tvp_action->property.directory_no_version_control || tvp_action->property.file_no_version_control))
   {
-    add_subaction (item, menu, "tvp::import", Q_("Menu|Import"), _("Import"), "network-workgroup", "--import");
+    add_subaction (item, menu, "tvp::import", _("Import"), _("Commit an unversioned file or tree into the repository"), "network-workgroup", "--import");
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction_u (menu, "tvp::info", Q_("Menu|Info"), _("Info"), "dialog-information", _("Info"));
+    /* unimplemented: add_subaction_u (menu, "tvp::info", _("Info"), _("Info"), "dialog-information", _("Info")); */
   }
 /* Ehmm...
   subitem = gtk_menu_item_new_with_label (_("List"));
@@ -342,12 +329,12 @@ tvp_svn_action_create_menu_item (ThunarxMenuItem *item)
 *//* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::lock", Q_("Menu|Lock"), _("Lock"), "dialog-password", "--lock");
+    add_subaction (item, menu, "tvp::lock", _("Lock"), _("Lock working copy paths in the repository so that no other user can commit changes to them"), "dialog-password", "--lock");
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::log", Q_("Menu|Log"), _("Log"), "gtk-index", "--log");
+    add_subaction (item, menu, "tvp::log", _("Log"), _("Show commit logs"), "gtk-index", "--log");
   }
 /* Ehmm ...
   subitem = gtk_menu_item_new_with_label (_("Merge"));
@@ -362,7 +349,7 @@ tvp_svn_action_create_menu_item (ThunarxMenuItem *item)
 *//* Version control (no parent) */
   if (!tvp_action->property.is_parent && tvp_action->property.parent_version_control && (tvp_action->property.directory_version_control || tvp_action->property.file_version_control))
   {
-    add_subaction (item, menu, "tvp::move", Q_("Menu|Move"), _("Move"), "gtk-dnd-multiple", "--move");
+    add_subaction (item, menu, "tvp::move", _("Move"), _("Move a file or directory"), "gtk-dnd-multiple", "--move");
   }
 /* Merged
   subitem = gtk_menu_item_new_with_label (_("Delete Properties"));
@@ -373,48 +360,48 @@ tvp_svn_action_create_menu_item (ThunarxMenuItem *item)
 *//* Version control */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::properties", Q_("Menu|Edit Properties"), _("Edit Properties"), "gtk-edit", "--properties");
+    add_subaction (item, menu, "tvp::properties", _("Edit Properties"), _("Edit the property of one or more items"), "gtk-edit", "--properties");
   }
   /* Version control (parent) */
   if (tvp_action->property.is_parent && tvp_action->property.parent_version_control)
   {
-    add_subaction (item, menu, "tvp::relocate", Q_("Menu|Relocate"), _("Relocate"), "edit-find-replace", "--relocate");
+    add_subaction (item, menu, "tvp::relocate", _("Relocate"), _("Relocate the working copy to point to a different repository root URL"), "edit-find-replace", "--relocate");
   }
 /* Changed
   subitem = gtk_menu_item_new_with_label (_("Mark Resolved"));
 */if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::resolved", Q_("Menu|Resolved"), _("Resolved"), "gtk-yes", "--resolved");
+    add_subaction (item, menu, "tvp::resolved", _("Resolved"), _("Remove \"conflicted\" state on working copy files or directories"), "gtk-yes", "--resolved");
   }/*
 *//* Version control (file) */
   if (tvp_action->property.file_version_control)
   {
-    add_subaction_u (menu, "tvp::resolve", Q_("Menu|Resolve"), _("Resolve"), "gtk-yes", _("Resolve"));
+    /* unimplemented: add_subaction_u (menu, "tvp::resolve", _("Resolve"), _("Resolve"), "gtk-yes", _("Resolve")); */
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::revert", Q_("Menu|Revert"), _("Revert"), "edit-undo", "--revert");
+    add_subaction (item, menu, "tvp::revert", _("Revert"), _("Undo all local edits"), "edit-undo", "--revert");
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::status", Q_("Menu|Status"), _("Status"), "dialog-information", "--status");
+    add_subaction (item, menu, "tvp::status", _("Status"), _("Show the working tree status"), "dialog-information", "--status");
   }
   /* Version control (parent) */
   if (tvp_action->property.is_parent && tvp_action->property.parent_version_control)
   {
-    add_subaction (item, menu, "tvp::switch", Q_("Menu|Switch"), _("Switch"), "go-jump", "--switch");
+    add_subaction (item, menu, "tvp::switch", _("Switch"), _("Update working copy to a different URL"), "go-jump", "--switch");
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::unlock", Q_("Menu|Unlock"), _("Unlock"), NULL, "--unlock");
+    add_subaction (item, menu, "tvp::unlock", _("Unlock"), _("Unlock working copy paths"), NULL, "--unlock");
   }
   /* Version control (all) */
   if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction (item, menu, "tvp::update", Q_("Menu|Update"), _("Update"), "view-refresh", "--update");
+    add_subaction (item, menu, "tvp::update", _("Update"), _("Update your working copy"), "view-refresh", "--update");
   }
 }
 
