@@ -20,8 +20,8 @@
 #include <config.h>
 #endif
 
+#include <exo/exo.h>
 #include <libxfce4util/libxfce4util.h>
-#include <gtk/gtk.h>
 
 #include "tgh-common.h"
 #include "tgh-blame-dialog.h"
@@ -122,17 +122,17 @@ tgh_blame_dialog_init (TghBlameDialog *dialog)
   g_object_unref (model);
 
   gtk_container_add (GTK_CONTAINER (scroll_window), tree_view);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), scroll_window, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), scroll_window, TRUE, TRUE, 0);
   gtk_widget_show (tree_view);
   gtk_widget_show (scroll_window);
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Blame"));
 
-  dialog->close = button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+  dialog->close = button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_CLOSE);
   gtk_widget_hide (button);
 
-  dialog->cancel = button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-  gtk_box_pack_end (GTK_BOX (GTK_DIALOG (dialog)->action_area), button, FALSE, TRUE, 0);
+  dialog->cancel = button = gtk_button_new_with_mnemonic(_("_Cancel"));
+  gtk_box_pack_end (GTK_BOX (exo_gtk_dialog_get_action_area (GTK_DIALOG (dialog))), button, FALSE, TRUE, 0);
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (cancel_clicked), dialog);
   gtk_widget_show (button);
 
@@ -156,13 +156,10 @@ tgh_blame_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags flag
   if(flags & GTK_DIALOG_DESTROY_WITH_PARENT)
     gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
 
-  if(flags & GTK_DIALOG_NO_SEPARATOR)
-    gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
-
   return GTK_WIDGET(dialog);
 }
 
-void       
+void
 tgh_blame_dialog_add (TghBlameDialog *dialog, gint64 line_no, const gchar *revision, const gchar *author, const gchar *date, const gchar *line)
 {
   GtkTreeModel *model;
@@ -201,4 +198,3 @@ cancel_clicked (GtkButton *button, gpointer user_data)
 
   g_signal_emit (dialog, signals[SIGNAL_CANCEL], 0);
 }
-
