@@ -21,7 +21,6 @@
 #endif
 
 #include <libxfce4util/libxfce4util.h>
-#include <gtk/gtk.h>
 
 #include "tgh-clean-dialog.h"
 
@@ -54,13 +53,13 @@ tgh_clean_dialog_init (TghCleanDialog *dialog)
   GtkCellRenderer *renderer;
 
   dialog->directories = gtk_check_button_new_with_label (_("Remove directories."));
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), dialog->directories, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), dialog->directories, FALSE, TRUE, 0);
   gtk_widget_show(dialog->directories);
 
   model = GTK_TREE_MODEL (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT));
 
   dialog->ignore = gtk_combo_box_new_with_model (model);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), dialog->ignore, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), dialog->ignore, FALSE, TRUE, 0);
   gtk_widget_show(dialog->ignore);
 
   gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -90,16 +89,15 @@ tgh_clean_dialog_init (TghCleanDialog *dialog)
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (dialog->ignore), renderer, "text", 0);
 
   dialog->force = gtk_check_button_new_with_label (_("Force clean."));
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), dialog->force, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), dialog->force, FALSE, TRUE, 0);
   gtk_widget_show(dialog->force);
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Clean"));
 
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-      GTK_STOCK_OK, GTK_RESPONSE_OK,
+      _("_Cancel"), GTK_RESPONSE_CANCEL,
+      _("_OK"), GTK_RESPONSE_OK,
       NULL);
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog), GTK_RESPONSE_OK, GTK_RESPONSE_CANCEL, -1);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -122,9 +120,6 @@ tgh_clean_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags flag
   if(flags & GTK_DIALOG_DESTROY_WITH_PARENT)
     gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
 
-  if(flags & GTK_DIALOG_NO_SEPARATOR)
-    gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
-
   return GTK_WIDGET(dialog);
 }
 
