@@ -1,17 +1,19 @@
 /*-
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,7 +27,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#include <thunar-vfs/thunar-vfs.h>
+#include <libxfce4util/libxfce4util.h>
 
 #include "tgh-common.h"
 #include "tgh-dialog-common.h"
@@ -43,21 +45,24 @@ static gboolean log_spawn (TghLogDialog *dialog, gchar **files, GPid *pid)
   gint i;
   gchar **argv;
 
-  length = 7;
+  length = 10;
   if(files)
     length += g_strv_length(files);
 
   argv = g_new(gchar*, length);
 
   argv[0] = "git";
-  argv[1] = "log";
-  argv[2] = "--numstat";
-  argv[3] = "--pretty=fuller";
-  argv[4] = "--boundary";
-  argv[5] = "--";
+  argv[1] = "--no-pager";
+  argv[2] = "log";
+  argv[3] = "--numstat";
+  argv[4] = "--parents";
+  argv[5] = "--pretty=fuller";
+  argv[6] = "--boundary";
+  argv[7] = "--date-order";
+  argv[8] = "--";
   argv[length-1] = NULL;
 
-  i = 6;
+  i = 9;
   if(files)
     while(*files)
       argv[i++] = *files++;
@@ -93,6 +98,26 @@ static void create_log_child(TghLogDialog *dialog, gpointer user_data)
 gboolean tgh_log (gchar **files, GPid *pid)
 {
   GtkWidget *dialog;
+  gchar *prefix;
+
+  prefix = tgh_common_prefix (files);
+
+  if (prefix)
+  {
+    if (chdir(prefix))
+    {
+      gchar *dirname = g_path_get_dirname (prefix);
+      if (chdir(dirname))
+      {
+        g_free (dirname);
+        return FALSE;
+      }
+      g_free (prefix);
+      prefix = dirname;
+    }
+    files = tgh_strip_prefix (files, prefix);
+    g_free (prefix);
+  }
 
   dialog = tgh_log_dialog_new (NULL, NULL, 0);
   g_signal_connect(dialog, "cancel-clicked", tgh_cancel, NULL);
@@ -100,18 +125,6 @@ gboolean tgh_log (gchar **files, GPid *pid)
 
   g_signal_connect(dialog, "refresh-clicked", G_CALLBACK(create_log_child), files);
 
-  if (files)
-    if (chdir(files[0]))
-    {
-      gchar *dirname = g_path_get_dirname (files[0]);
-      if (chdir(dirname))
-      {
-        g_free (dirname);
-        return FALSE;
-      }
-      g_free (dirname);
-    }
-
   return log_spawn(TGH_LOG_DIALOG(dialog), files, pid);
 }
 
