@@ -145,8 +145,8 @@ gboolean tgh_move (gchar **files, GPid *pid)
 
   dialog = gtk_file_chooser_dialog_new (_("Move To"), NULL,
       multiple?GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER:GTK_FILE_CHOOSER_ACTION_SAVE,
-      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-      GTK_STOCK_OK, GTK_RESPONSE_OK,
+      _("_Cancel"), GTK_RESPONSE_CANCEL,
+      _("_OK"), GTK_RESPONSE_OK,
       NULL);
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_OK)
@@ -159,7 +159,7 @@ gboolean tgh_move (gchar **files, GPid *pid)
 
   gtk_widget_destroy (dialog);
 
-  dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_OTHER, GTK_BUTTONS_CANCEL, _("Move ..."));
+  dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_OTHER, GTK_BUTTONS_CANCEL, _("Move..."));
   g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (tgh_cancel), NULL);
   tgh_dialog_start (GTK_DIALOG (dialog), TRUE);
 
