@@ -20,8 +20,8 @@
 #include <config.h>
 #endif
 
+#include <exo/exo.h>
 #include <libxfce4util/libxfce4util.h>
-#include <gtk/gtk.h>
 
 #include "tgh-common.h"
 #include "tgh-dialog-common.h"
@@ -145,11 +145,10 @@ tgh_stash_dialog_init (TghStashDialog *dialog)
   GtkWidget *file_view;
   GtkWidget *scroll_window;
   GtkWidget *vpane;
-  GtkWidget *box;
   GtkCellRenderer *renderer;
   GtkTreeModel *model;
 
-  vpane = gtk_vpaned_new ();
+  vpane = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
 
   scroll_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -180,7 +179,7 @@ tgh_stash_dialog_init (TghStashDialog *dialog)
 
   g_object_unref (model);
 
-  g_signal_connect (G_OBJECT (tree_view), "cursor-changed", G_CALLBACK (selection_changed), dialog); 
+  g_signal_connect (G_OBJECT (tree_view), "cursor-changed", G_CALLBACK (selection_changed), dialog);
 
   gtk_container_add (GTK_CONTAINER (scroll_window), tree_view);
   gtk_paned_pack1 (GTK_PANED(vpane), scroll_window, TRUE, FALSE);
@@ -216,55 +215,44 @@ tgh_stash_dialog_init (TghStashDialog *dialog)
   gtk_widget_show (file_view);
   gtk_widget_show (scroll_window);
 
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vpane, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), vpane, TRUE, TRUE, 0);
   gtk_widget_show (vpane);
 
-  //gtk_button_box_set_layout(GTK_BUTTON_BOX (GTK_DIALOG (dialog)->action_area), GTK_BUTTONBOX_EDGE);
-  tgh_dialog_replace_action_area (GTK_DIALOG (dialog));
-  box = GTK_DIALOG (dialog)->action_area;
-
-  //box = gtk_hbox_new (FALSE, 12);
-
-  dialog->save = button = gtk_button_new_from_stock(GTK_STOCK_SAVE);
-  gtk_box_pack_start (GTK_BOX (box), button, FALSE, TRUE, 0);
+  dialog->save = button = gtk_button_new_with_mnemonic (_("_Save"));
+  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 0);
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (save_clicked), dialog);
   gtk_widget_show (button);
 
-  dialog->apply = button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
-  gtk_box_pack_start (GTK_BOX (box), button, FALSE, TRUE, 0);
+  dialog->apply = button = gtk_button_new_with_mnemonic (_("_Apply"));
+  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 0);
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (apply_clicked), dialog);
   gtk_widget_show (button);
 
-  dialog->pop = button = gtk_button_new_from_stock(GTK_STOCK_OK);
-  gtk_box_pack_start (GTK_BOX (box), button, FALSE, TRUE, 0);
+  dialog->pop = button = gtk_button_new_with_mnemonic (_("_OK"));
+  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 0);
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (pop_clicked), dialog);
   gtk_widget_show (button);
 
-  dialog->drop = button = gtk_button_new_from_stock(GTK_STOCK_DELETE);
-  gtk_box_pack_start (GTK_BOX (box), button, FALSE, TRUE, 0);
+  dialog->drop = button = gtk_button_new_with_mnemonic (_("_Delete"));
+  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 0);
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (drop_clicked), dialog);
   gtk_widget_show (button);
 
-  dialog->clear = button = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
-  gtk_box_pack_start (GTK_BOX (box), button, FALSE, TRUE, 0);
+  dialog->clear = button = gtk_button_new_with_mnemonic (_("C_lear"));
+  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 0);
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (clear_clicked), dialog);
   gtk_widget_show (button);
 
-  //gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), box, FALSE, TRUE, 0);
-  //gtk_widget_show (box);
-
   gtk_window_set_title (GTK_WINDOW (dialog), _("Stash"));
 
-  dialog->close = button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+  dialog->close = button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_CLOSE);
   gtk_widget_hide (button);
 
-  dialog->cancel = button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-  gtk_box_pack_end (GTK_BOX (GTK_DIALOG (dialog)->action_area), button, FALSE, TRUE, 0);
+  dialog->cancel = button = gtk_button_new_with_mnemonic (_("_Cancel"));
+  gtk_box_pack_end (GTK_BOX (exo_gtk_dialog_get_action_area (GTK_DIALOG (dialog))), button, FALSE, TRUE, 0);
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (cancel_clicked), dialog);
   gtk_widget_show (button);
 
-  tgh_make_homogeneous (dialog->save, dialog->apply, dialog->pop, dialog->drop, dialog->close, dialog->cancel, NULL);
-
   gtk_window_set_default_size (GTK_WINDOW (dialog), 500, 400);
 }
 
@@ -285,13 +273,10 @@ tgh_stash_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags flag
   if(flags & GTK_DIALOG_DESTROY_WITH_PARENT)
     gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
 
-  if(flags & GTK_DIALOG_NO_SEPARATOR)
-    gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
-
   return GTK_WIDGET(dialog);
 }
 
-void       
+void
 tgh_stash_dialog_add (TghStashDialog *dialog, const gchar *name, const gchar *branch, const gchar *description)
 {
   GtkTreeModel *model;
@@ -309,7 +294,7 @@ tgh_stash_dialog_add (TghStashDialog *dialog, const gchar *name, const gchar *br
       -1);
 }
 
-void       
+void
 tgh_stash_dialog_add_file (TghStashDialog *dialog, guint insertions, guint deletions, const gchar *file)
 {
   GtkTreeModel *model;
@@ -390,21 +375,22 @@ save_clicked (GtkButton *button, gpointer user_data)
   gchar *name;
   gint result;
 
-  name_dialog = gtk_dialog_new_with_buttons (NULL, GTK_WINDOW (dialog), GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1);
+  name_dialog = gtk_dialog_new_with_buttons (NULL, GTK_WINDOW (dialog), GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL, _("_Cancel"), GTK_RESPONSE_CANCEL, _("_Save"), GTK_RESPONSE_ACCEPT, NULL);
   gtk_window_set_resizable (GTK_WINDOW (name_dialog), FALSE);
   gtk_window_set_skip_taskbar_hint (GTK_WINDOW (name_dialog), TRUE);
 
   label = gtk_label_new (_("Stash description:"));
-  image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
-  gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-  
-  gtk_misc_set_alignment   (GTK_MISC  (label), 0.0, 0.0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.0f);
+
+  image = gtk_image_new_from_icon_name ("dialog-question", GTK_ICON_SIZE_DIALOG);
+  gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign (image, GTK_ALIGN_START);
 
   desc_entry = gtk_entry_new ();
-  
-  hbox = gtk_hbox_new (FALSE, 12);
-  vbox = gtk_vbox_new (FALSE, 12);
+
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 
   gtk_box_pack_start (GTK_BOX (vbox), label,
                       FALSE, FALSE, 0);
@@ -424,9 +410,9 @@ save_clicked (GtkButton *button, gpointer user_data)
 
   gtk_container_set_border_width (GTK_CONTAINER (name_dialog), 5);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (name_dialog)->vbox), 14); /* 14 + 2 * 5 = 24 */
-  gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (name_dialog))), 5);
-  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (name_dialog))), 6);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (name_dialog))), 14); /* 14 + 2 * 5 = 24 */
+  gtk_container_set_border_width (GTK_CONTAINER (exo_gtk_dialog_get_action_area (GTK_DIALOG (name_dialog))), 5);
+  gtk_box_set_spacing (GTK_BOX (exo_gtk_dialog_get_action_area (GTK_DIALOG (name_dialog))), 6);
 
   gtk_widget_show_all (hbox);
 
@@ -575,4 +561,3 @@ clear_clicked (GtkButton *button, gpointer user_data)
 
   g_signal_emit (dialog, signals[SIGNAL_CLEAR], 0);
 }
-
