@@ -20,10 +20,10 @@
 #include <config.h>
 #endif
 
-#include <libxfce4util/libxfce4util.h>
-#include <gtk/gtk.h>
 #include <dirent.h>
 
+#include <libxfce4util/libxfce4util.h>
+
 #include "tgh-transfer-dialog.h"
 
 static void browse_callback(GtkButton *, TghTransferDialog *);
@@ -52,34 +52,29 @@ tgh_transfer_dialog_class_init (TghTransferDialogClass *klass)
 static void
 tgh_transfer_dialog_init (TghTransferDialog *dialog)
 {
-    GtkWidget *table;
+    GtkWidget *grid;
     GtkWidget *label;
     GtkWidget *box;
     GtkWidget *button;
     GtkWidget *image;
 
-    table = gtk_table_new (2, 2, FALSE);
+    grid = gtk_grid_new ();
 
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, FALSE, TRUE, 0);
-    gtk_widget_show (table);
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), grid, FALSE, TRUE, 0);
+    gtk_widget_show (grid);
 
     label = gtk_label_new_with_mnemonic (_("_Repository:"));
-    gtk_table_attach (GTK_TABLE (table), label,
-            0, 1, 0, 1,
-            GTK_FILL,
-            GTK_FILL,
-            0, 0);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 
-    box = gtk_hbox_new(FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     dialog->repository = gtk_entry_new();
     dialog->filechooser = gtk_file_chooser_dialog_new(_("Select a folder"), GTK_WINDOW(dialog),
             GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-            GTK_STOCK_OK, GTK_RESPONSE_OK,
+            _("_Cancel"), GTK_RESPONSE_CANCEL,
+            _("_OK"), GTK_RESPONSE_OK,
             NULL);
 
-    image = gtk_image_new_from_stock (GTK_STOCK_OPEN,
-            GTK_ICON_SIZE_MENU);
+    image = gtk_image_new_from_icon_name ("document-open", GTK_ICON_SIZE_MENU);
     button = gtk_button_new();
     gtk_button_set_image(GTK_BUTTON(button), image);
     g_signal_connect(button, "clicked", G_CALLBACK(browse_callback), dialog);
@@ -90,30 +85,19 @@ tgh_transfer_dialog_init (TghTransferDialog *dialog)
     gtk_widget_show(dialog->repository);
     gtk_widget_show(button);
 
-    gtk_table_attach (GTK_TABLE (table), box,
-            1, 2, 0, 1,
-            GTK_EXPAND | GTK_FILL,
-            GTK_FILL,
-            0, 0);
+    gtk_widget_set_hexpand (box, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), box, 1, 0, 1, 1);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->repository);
     gtk_widget_show(label);
     gtk_widget_show(box);
 
     label = gtk_label_new_with_mnemonic (_("_Directory:"));
-    gtk_table_attach (GTK_TABLE (table), label,
-            0, 1, 1, 2,
-            GTK_FILL,
-            GTK_FILL,
-            0, 0);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 
     dialog->path = gtk_file_chooser_button_new (_("Select a folder"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-    //dialog->path = gtk_file_chooser_entry_new(_("Select a folder"), GTK_FILE_CHOOSER_ACTION_OPEN);//GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);//tgh_file_chooser_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), dialog->path,
-            1, 2, 1, 2,
-            GTK_EXPAND | GTK_FILL,
-            GTK_FILL,
-            0, 0);
+    gtk_widget_set_hexpand (dialog->path, TRUE);
+    gtk_grid_attach (GTK_GRID (grid), dialog->path, 1, 1, 1, 1);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->path);
     gtk_widget_show(label);
@@ -122,10 +106,9 @@ tgh_transfer_dialog_init (TghTransferDialog *dialog)
     gtk_window_set_title (GTK_WINDOW (dialog), _("Transfer"));
 
     gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-            GTK_STOCK_OK, GTK_RESPONSE_OK,
+            _("_Cancel"), GTK_RESPONSE_CANCEL,
+            _("_OK"), GTK_RESPONSE_OK,
             NULL);
-    gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog), GTK_RESPONSE_OK, GTK_RESPONSE_CANCEL, -1);
     gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -148,9 +131,6 @@ tgh_transfer_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags f
     if(flags & GTK_DIALOG_DESTROY_WITH_PARENT)
         gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
 
-    if(flags & GTK_DIALOG_NO_SEPARATOR)
-        gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
-
     if(repo_dir)
     {
       gchar *absolute = NULL;
@@ -224,4 +204,3 @@ browse_callback(GtkButton *button, TghTransferDialog *dialog)
     }
     gtk_widget_hide(dialog->filechooser);
 }
-
