@@ -36,7 +36,6 @@
 #include "tsh-common.h"
 #include "tsh-add.h"
 #include "tsh-blame.h"
-//#include "tsh-changelist.h"
 #include "tsh-checkout.h"
 #include "tsh-cleanup.h"
 #include "tsh-commit.h"
@@ -246,10 +245,9 @@ int main (int argc, char *argv[])
   /* setup translation domain */
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
-  if (!g_thread_supported ())
-    g_thread_init (NULL);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gdk_threads_init ();
-  gdk_threads_enter ();
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 	option_context = g_option_context_new("<action> [options] [args]");
 
@@ -508,8 +506,6 @@ int main (int argc, char *argv[])
 
 	svn_pool_destroy(pool);
 
-  gdk_threads_leave ();
-
 	return EXIT_SUCCESS;
 }
 
