@@ -30,6 +30,7 @@
 #include <libxfce4util/libxfce4util.h>
 
 #include <subversion-1/svn_client.h>
+#include <subversion-1/svn_path.h>
 #include <subversion-1/svn_pools.h>
 
 #include "tsh-common.h"
@@ -44,6 +45,26 @@ struct thread_args {
 	gchar *path;
 };
 
+static svn_error_t * tsh_client_cleanup(const char *path,
+                                        svn_client_ctx_t *ctx,
+                                        apr_pool_t *scratch_pool)
+{
+#if CHECK_SVN_VERSION_G(1,9)
+  const char *local_abspath;
+
+  if (svn_path_is_url(path))
+    return svn_error_createf(SVN_ERR_ILLEGAL_TARGET, NULL,
+                             _("'%s' is not a local path"), path);
+
+  svn_dirent_get_absolute(&local_abspath, path, scratch_pool);
+
+  return svn_client_cleanup2(local_abspath, TRUE, TRUE, TRUE, TRUE, FALSE, ctx,
+                             scratch_pool);
+#else
+  return svn_client_cleanup(path, ctx, scratch_pool);
+#endif
+}
+
 static gpointer cleanup_thread (gpointer user_data)
 {
 	struct thread_args *args = user_data;
@@ -58,17 +79,25 @@ static gpointer cleanup_thread (gpointer user_data)
 
   subpool = svn_pool_create (pool);
 
-	if ((err = svn_client_cleanup(path, ctx, subpool)))
+	if ((err = tsh_client_cleanup(path, ctx, subpool)))
 	{
     svn_pool_destroy (subpool);
 
     error_str = tsh_strerror(err);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gdk_threads_enter();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
     gtk_widget_destroy(dialog);
     dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Cleanup failed"));
     gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog), "%s", error_str);
     tsh_dialog_start(GTK_DIALOG(dialog), TRUE);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
     g_free(error_str);
 
 		svn_error_clear(err);
@@ -78,11 +107,17 @@ static gpointer cleanup_thread (gpointer user_data)
 
   svn_pool_destroy (subpool);
 
-	gdk_threads_enter();
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  gdk_threads_enter();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
   gtk_widget_destroy(dialog);
   dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_OTHER, GTK_BUTTONS_CLOSE, _("Cleanup finished"));
   tsh_dialog_start(GTK_DIALOG(dialog), TRUE);
-	gdk_threads_leave();
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   tsh_reset_cancel();
 	return GINT_TO_POINTER (TRUE);
@@ -94,7 +129,7 @@ GThread *tsh_cleanup (gchar **files, svn_client_ctx_t *ctx, apr_pool_t *pool)
   GtkWidget *dialog;
   gchar *path;
 
-  dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_OTHER, GTK_BUTTONS_CANCEL, _("Cleaning up ..."));
+  dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_OTHER, GTK_BUTTONS_CANCEL, _("Cleaning up..."));
 	g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (tsh_cancel), NULL);
   tsh_dialog_start(GTK_DIALOG(dialog), TRUE);
 
@@ -106,6 +141,6 @@ GThread *tsh_cleanup (gchar **files, svn_client_ctx_t *ctx, apr_pool_t *pool)
   args->dialog = dialog;
 	args->path = path;
 
-	return g_thread_create (cleanup_thread, args, TRUE, NULL);
+	return g_thread_new (NULL, cleanup_thread, args);
 }
 
