@@ -21,9 +21,7 @@
 #endif
 
 #include <libxfce4util/libxfce4util.h>
-#include <gtk/gtk.h>
 
-#include <subversion-1/svn_version.h>
 #include <subversion-1/svn_client.h>
 #include <subversion-1/svn_pools.h>
 
@@ -137,7 +135,7 @@ tsh_file_selection_dialog_init (TshFileSelectionDialog *dialog)
 	g_object_unref (model);
 
 	gtk_container_add (GTK_CONTAINER (scroll_window), tree_view);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), scroll_window, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), scroll_window, TRUE, TRUE, 0);
 	gtk_widget_show (tree_view);
 	gtk_widget_show (scroll_window);
 
@@ -145,16 +143,15 @@ tsh_file_selection_dialog_init (TshFileSelectionDialog *dialog)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (all), TRUE);
   gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (all), TRUE);
   g_signal_connect (all, "toggled", G_CALLBACK (selection_all_toggled), dialog);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), all, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), all, FALSE, FALSE, 0);
 	gtk_widget_show (all);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Status"));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-	                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-	                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+	                        _("_Cancel"), GTK_RESPONSE_CANCEL,
+	                        _("_OK"), GTK_RESPONSE_OK,
 	                        NULL);
-	gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog), GTK_RESPONSE_OK, GTK_RESPONSE_CANCEL, -1);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 200);
@@ -181,9 +178,6 @@ tsh_file_selection_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogF
   if(flags & GTK_DIALOG_DESTROY_WITH_PARENT)
     gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
 
-  if(flags & GTK_DIALOG_NO_SEPARATOR)
-    gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
-
   dialog->flags = selection_flags;
 
   subpool = svn_pool_create (pool);
@@ -194,17 +188,45 @@ tsh_file_selection_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogF
     while (*files)
     {
       svn_pool_clear(subpool);
-#if CHECK_SVN_VERSION(1,5)
-      if((err = svn_client_status3(NULL, *files, &revision, tsh_file_selection_status_func2, dialog, (selection_flags&TSH_FILE_SELECTION_FLAG_RECURSIVE)?svn_depth_infinity:svn_depth_immediates, selection_flags&TSH_FILE_SELECTION_FLAG_UNCHANGED, FALSE, selection_flags&TSH_FILE_SELECTION_FLAG_IGNORED, TRUE, NULL, ctx, subpool)))
-#elif CHECK_SVN_VERSION(1,6)
-      if((err = svn_client_status4(NULL, *files, &revision, tsh_file_selection_status_func3, dialog, (selection_flags&TSH_FILE_SELECTION_FLAG_RECURSIVE)?svn_depth_infinity:svn_depth_immediates, selection_flags&TSH_FILE_SELECTION_FLAG_UNCHANGED, FALSE, selection_flags&TSH_FILE_SELECTION_FLAG_IGNORED, TRUE, NULL, ctx, subpool)))
-#else /* CHECK_SVN_VERSION(1,7) */
-      if((err = svn_client_status5(NULL, ctx, *files, &revision, (selection_flags&TSH_FILE_SELECTION_FLAG_RECURSIVE)?svn_depth_infinity:svn_depth_immediates, selection_flags&TSH_FILE_SELECTION_FLAG_UNCHANGED, FALSE, selection_flags&TSH_FILE_SELECTION_FLAG_IGNORED, TRUE, TRUE, NULL, tsh_file_selection_status_func, dialog, subpool)))
+
+#if CHECK_SVN_VERSION_G(1,9)
+      if((err = svn_client_status6(NULL, ctx, *files, &revision,
+                                   (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                     svn_depth_infinity : svn_depth_immediates,
+                                   selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                                   FALSE, TRUE,
+                                   selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                                   TRUE, TRUE, NULL,
+                                   tsh_file_selection_status_func, dialog, subpool)))
+#elif CHECK_SVN_VERSION_G(1,7)
+      if((err = svn_client_status5(NULL, ctx, *files, &revision,
+                                   (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                     svn_depth_infinity : svn_depth_immediates,
+                                   selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                                   FALSE, selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                                   TRUE, TRUE, NULL,
+                                   tsh_file_selection_status_func, dialog, subpool)))
+#elif CHECK_SVN_VERSION_G(1,6)
+      if((err = svn_client_status4(NULL, *files, &revision,
+                                   tsh_file_selection_status_func3, dialog,
+                                   (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                     svn_depth_infinity : svn_depth_immediates,
+                                   selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                                   FALSE, selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                                   TRUE, NULL, ctx, subpool)))
+#else
+      if((err = svn_client_status3(NULL, *files, &revision,
+                                   tsh_file_selection_status_func2, dialog,
+                                   (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                     svn_depth_infinity : svn_depth_immediates,
+                                   selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                                   FALSE, selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                                   TRUE, NULL, ctx, subpool)))
 #endif
       {
 	svn_pool_destroy (subpool);
 
-	gtk_widget_unref(GTK_WIDGET(dialog));
+	g_object_unref(GTK_WIDGET(dialog));
 
 	svn_error_clear(err);
 	return NULL;  //FIXME: needed ??
@@ -214,17 +236,44 @@ tsh_file_selection_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogF
   }
   else
   {
-#if CHECK_SVN_VERSION(1,5)
-    if((err = svn_client_status3(NULL, "", &revision, tsh_file_selection_status_func2, dialog, (selection_flags&TSH_FILE_SELECTION_FLAG_RECURSIVE)?svn_depth_infinity:svn_depth_immediates, selection_flags&TSH_FILE_SELECTION_FLAG_UNCHANGED, FALSE, selection_flags&TSH_FILE_SELECTION_FLAG_IGNORED, TRUE, NULL, ctx, subpool)))
+
+#if CHECK_SVN_VERSION_G(1,9)
+  if((err = svn_client_status6(NULL, ctx, "", &revision,
+                               (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                 svn_depth_infinity : svn_depth_immediates,
+                               selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                               FALSE, TRUE, selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                               TRUE, TRUE, NULL, tsh_file_selection_status_func,
+                               dialog, subpool)))
+#elif CHECK_SVN_VERSION_G(1,7)
+  if((err = svn_client_status5(NULL, ctx, "", &revision,
+                               (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                 svn_depth_infinity : svn_depth_immediates,
+                               selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                               FALSE, selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                               TRUE, TRUE, NULL, tsh_file_selection_status_func,
+                               dialog, subpool)))
 #elif CHECK_SVN_VERSION(1,6)
-    if((err = svn_client_status4(NULL, "", &revision, tsh_file_selection_status_func3, dialog, (selection_flags&TSH_FILE_SELECTION_FLAG_RECURSIVE)?svn_depth_infinity:svn_depth_immediates, selection_flags&TSH_FILE_SELECTION_FLAG_UNCHANGED, FALSE, selection_flags&TSH_FILE_SELECTION_FLAG_IGNORED, TRUE, NULL, ctx, subpool)))
-#else /* CHECK_SVN_VERSION(1,7) */
-    if((err = svn_client_status5(NULL, ctx, "", &revision, (selection_flags&TSH_FILE_SELECTION_FLAG_RECURSIVE)?svn_depth_infinity:svn_depth_immediates, selection_flags&TSH_FILE_SELECTION_FLAG_UNCHANGED, FALSE, selection_flags&TSH_FILE_SELECTION_FLAG_IGNORED, TRUE, TRUE, NULL, tsh_file_selection_status_func, dialog, subpool)))
+    if((err = svn_client_status4(NULL, "", &revision,
+                                 tsh_file_selection_status_func3, dialog,
+                                 (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                   svn_depth_infinity : svn_depth_immediates,
+                                 selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                                 FALSE, selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                                 TRUE, NULL, ctx, subpool)))
+#else
+    if((err = svn_client_status3(NULL, "", &revision, 
+                                 tsh_file_selection_status_func2, dialog,
+                                 (selection_flags & TSH_FILE_SELECTION_FLAG_RECURSIVE) ?
+                                   svn_depth_infinity : svn_depth_immediates,
+                                 selection_flags & TSH_FILE_SELECTION_FLAG_UNCHANGED,
+                                 FALSE, selection_flags & TSH_FILE_SELECTION_FLAG_IGNORED,
+                                 TRUE, NULL, ctx, subpool)))
 #endif
     {
       svn_pool_destroy (subpool);
 
-      gtk_widget_unref(GTK_WIDGET(dialog));
+      g_object_unref(GTK_WIDGET(dialog));
 
       svn_error_clear(err);
       return NULL;
