@@ -21,7 +21,6 @@
 #endif
 
 #include <libxfce4util/libxfce4util.h>
-#include <gtk/gtk.h>
 
 #include "tsh-lock-dialog.h"
 
@@ -61,20 +60,19 @@ tsh_lock_dialog_init (TshLockDialog *dialog)
 	gtk_container_add (GTK_CONTAINER (scroll_window), text_view);
 	gtk_widget_show (text_view);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), scroll_window, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), scroll_window, TRUE, TRUE, 0);
 	gtk_widget_show (scroll_window);
 
   dialog->steal = steal = gtk_check_button_new_with_label("Steal Lock");
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), steal, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), steal, FALSE, FALSE, 0);
 	gtk_widget_show (steal);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Lock"));
 
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                          GTK_STOCK_OK, GTK_RESPONSE_OK,
+                          _("_Cancel"), GTK_RESPONSE_CANCEL,
+                          _("_OK"), GTK_RESPONSE_OK,
                           NULL);
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog), GTK_RESPONSE_OK, GTK_RESPONSE_CANCEL, -1);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 200);
@@ -97,9 +95,6 @@ tsh_lock_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags flags
 	if(flags & GTK_DIALOG_DESTROY_WITH_PARENT)
 		gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
 
-	if(flags & GTK_DIALOG_NO_SEPARATOR)
-		gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
-
 	return GTK_WIDGET(dialog);
 }
 
