@@ -89,10 +89,14 @@ static gpointer lock_thread (gpointer user_data)
     svn_pool_destroy (subpool);
 
     error_str = tsh_strerror(err);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 		gdk_threads_enter();
     tsh_notify_dialog_add(dialog, _("Failed"), error_str, NULL);
 		tsh_notify_dialog_done (dialog);
-		gdk_threads_leave();
+    gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
     g_free(error_str);
 
 		svn_error_clear(err);
@@ -102,10 +106,12 @@ static gpointer lock_thread (gpointer user_data)
 
   svn_pool_destroy (subpool);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gdk_threads_enter();
 	tsh_notify_dialog_done (dialog);
-	gdk_threads_leave();
-	
+  gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
   tsh_reset_cancel();
 	return GINT_TO_POINTER (TRUE);
 }
@@ -144,6 +150,6 @@ GThread *tsh_lock (gchar **files, svn_client_ctx_t *ctx, apr_pool_t *pool)
   args->message = message;
   args->steal = steal;
 
-	return g_thread_create (lock_thread, args, TRUE, NULL);
+	return g_thread_new (NULL, lock_thread, args);
 }
 
