@@ -71,9 +71,13 @@ static gpointer resolved_thread (gpointer user_data)
       if ((err = svn_client_resolve(files[i], svn_depth_empty, svn_wc_conflict_choose_merged, ctx, subpool)))
       {
         error_str = tsh_strerror(err);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         gdk_threads_enter();
         tsh_notify_dialog_add(dialog, _("Failed"), error_str, NULL);
         gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
         g_free(error_str);
 
         svn_error_clear(err);
@@ -87,9 +91,13 @@ static gpointer resolved_thread (gpointer user_data)
     if ((err = svn_client_resolve("", svn_depth_empty, svn_wc_conflict_choose_merged, ctx, subpool)))
     {
       error_str = tsh_strerror(err);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       gdk_threads_enter();
       tsh_notify_dialog_add(dialog, _("Failed"), error_str, NULL);
       gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
       g_free(error_str);
 
       svn_error_clear(err);
@@ -99,10 +107,12 @@ static gpointer resolved_thread (gpointer user_data)
 
   svn_pool_destroy (subpool);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gdk_threads_enter();
 	tsh_notify_dialog_done (dialog);
 	gdk_threads_leave();
-	
+G_GNUC_END_IGNORE_DEPRECATIONS
+
   tsh_reset_cancel();
 	return GINT_TO_POINTER (result);
 }
@@ -138,6 +148,6 @@ GThread *tsh_resolved (gchar **files, svn_client_ctx_t *ctx, apr_pool_t *pool)
 	args->dialog = TSH_NOTIFY_DIALOG (dialog);
 	args->files = files;
 
-	return g_thread_create (resolved_thread, args, TRUE, NULL);
+	return g_thread_new (NULL, resolved_thread, args);
 }
 
