@@ -80,15 +80,24 @@ static gpointer revert_thread (gpointer user_data)
 		APR_ARRAY_PUSH (paths, const char *) = ""; // current directory
 	}
 
+#if CHECK_SVN_VERSION_G(1,9)
+	if ((err = svn_client_revert3(paths, svn_depth_empty, NULL, FALSE, FALSE,
+                                ctx, subpool)))
+#else
 	if ((err = svn_client_revert2(paths, svn_depth_empty, NULL, ctx, subpool)))
+#endif
 	{
     svn_pool_destroy (subpool);
 
     error_str = tsh_strerror(err);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 		gdk_threads_enter();
     tsh_notify_dialog_add(dialog, _("Failed"), error_str, NULL);
 		tsh_notify_dialog_done (dialog);
 		gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
     g_free(error_str);
 
 		svn_error_clear(err);
@@ -98,9 +107,11 @@ static gpointer revert_thread (gpointer user_data)
 
   svn_pool_destroy (subpool);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gdk_threads_enter();
 	tsh_notify_dialog_done (dialog);
 	gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
 	
   tsh_reset_cancel();
 	return GINT_TO_POINTER (TRUE);
@@ -137,6 +148,6 @@ GThread *tsh_revert (gchar **files, svn_client_ctx_t *ctx, apr_pool_t *pool)
 	args->dialog = TSH_NOTIFY_DIALOG (dialog);
 	args->files = files;
 
-	return g_thread_create (revert_thread, args, TRUE, NULL);
+	return g_thread_new (NULL, revert_thread, args);
 }
 
