@@ -20,8 +20,8 @@
 #include <config.h>
 #endif
 
+#include <exo/exo.h>
 #include <libxfce4util/libxfce4util.h>
-#include <gtk/gtk.h>
 
 #include <subversion-1/svn_client.h>
 
@@ -102,10 +102,10 @@ tsh_status_dialog_init (TshStatusDialog *dialog)
 	GtkWidget *update;
 	GtkWidget *no_ignore;
 	GtkWidget *ignore_externals;
-  GtkWidget *table;
+	GtkWidget *grid;
 	GtkCellRenderer *renderer;
 	GtkTreeModel *model;
-    GtkTreeIter iter;
+	GtkTreeIter iter;
 
 	scroll_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -117,25 +117,25 @@ tsh_status_dialog_init (TshStatusDialog *dialog)
 	                                             -1, _("Path"),
 	                                             renderer, "text",
 	                                             COLUMN_PATH, NULL);
-	
+
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
 	                                             -1, _("State"),
 	                                             renderer, "text",
 	                                             COLUMN_TEXT_STAT, NULL);
-	
+
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
 	                                             -1, _("Prop state"),
 	                                             renderer, "text",
 	                                             COLUMN_PROP_STAT, NULL);
-	
+
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
 	                                             -1, _("Repo state"),
 	                                             renderer, "text",
 	                                             COLUMN_REPO_TEXT_STAT, NULL);
-	
+
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
 	                                             -1, _("Repo prop state"),
@@ -149,11 +149,11 @@ tsh_status_dialog_init (TshStatusDialog *dialog)
 	g_object_unref (model);
 
 	gtk_container_add (GTK_CONTAINER (scroll_window), tree_view);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), scroll_window, TRUE, TRUE, 5);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), scroll_window, TRUE, TRUE, 5);
 	gtk_widget_show (tree_view);
 	gtk_widget_show (scroll_window);
 
-  table = gtk_table_new (3, 2, FALSE);
+  grid = gtk_grid_new ();
 
 	model = GTK_TREE_MODEL (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT));
 
@@ -217,47 +217,53 @@ tsh_status_dialog_init (TshStatusDialog *dialog)
     gtk_cell_layout_pack_start(GTK_CELL_LAYOUT (depth), renderer, TRUE);
     gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (depth), renderer, "text", 0);
 
-  gtk_table_attach (GTK_TABLE (table), depth, 0, 1, 0, 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_widget_set_hexpand (depth, TRUE);
+	gtk_grid_attach (GTK_GRID (grid), depth, 0, 0, 1, 1);
 	gtk_widget_show (depth);
 
 	dialog->get_all = get_all = gtk_check_button_new_with_label (_("Show Unmodified Files"));
-  gtk_table_attach (GTK_TABLE (table), get_all, 0, 1, 1, 2, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_widget_set_hexpand (get_all, TRUE);
+	gtk_grid_attach (GTK_GRID (grid), get_all, 0, 1, 1, 1);
 	gtk_widget_show (get_all);
 
 	dialog->unversioned = unversioned = gtk_check_button_new_with_label (_("Show Unversioned Files"));
-  gtk_table_attach (GTK_TABLE (table), unversioned, 0, 1, 2, 3, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_widget_set_hexpand (unversioned, TRUE);
+	gtk_grid_attach (GTK_GRID (grid), unversioned, 0, 2, 1, 1);
 	gtk_widget_show (unversioned);
 
 	dialog->no_ignore = no_ignore = gtk_check_button_new_with_label (_("Show Ignored Files"));
-  gtk_table_attach (GTK_TABLE (table), no_ignore, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_widget_set_hexpand (no_ignore, TRUE);
+	gtk_grid_attach (GTK_GRID (grid), no_ignore, 1, 0, 1, 1);
 	gtk_widget_show (no_ignore);
 
 	dialog->ignore_externals = ignore_externals = gtk_check_button_new_with_label (_("Hide Externals"));
-  gtk_table_attach (GTK_TABLE (table), ignore_externals, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_widget_set_hexpand (ignore_externals, TRUE);
+	gtk_grid_attach (GTK_GRID (grid), ignore_externals, 1, 1, 1, 1);
 	gtk_widget_show (ignore_externals);
 
 	dialog->update = update = gtk_check_button_new_with_label (_("Check Repository"));
-  gtk_table_attach (GTK_TABLE (table), update, 1, 2, 2, 3, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+	gtk_widget_set_hexpand (update, TRUE);
+	gtk_grid_attach (GTK_GRID (grid), update, 1, 2, 1, 1);
 	gtk_widget_show (update);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, FALSE, FALSE, 0);
-  gtk_widget_show (table);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), grid, FALSE, FALSE, 0);
+	gtk_widget_show (grid);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Status"));
 
-  gtk_button_box_set_layout(GTK_BUTTON_BOX (GTK_DIALOG (dialog)->action_area), GTK_BUTTONBOX_EDGE);
+	gtk_button_box_set_layout(GTK_BUTTON_BOX (exo_gtk_dialog_get_action_area (GTK_DIALOG (dialog))), GTK_BUTTONBOX_EDGE);
 
-	dialog->cancel = button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), button, FALSE, TRUE, 0);
+	dialog->cancel = button = gtk_button_new_with_mnemonic (_("_Cancel"));
+	gtk_box_pack_start (GTK_BOX (exo_gtk_dialog_get_action_area (GTK_DIALOG (dialog))), button, FALSE, TRUE, 0);
 	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (cancel_clicked), dialog);
 	gtk_widget_show (button);
 
-	dialog->refresh = button = gtk_button_new_from_stock(GTK_STOCK_REFRESH);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), button, FALSE, TRUE, 0);
+	dialog->refresh = button = gtk_button_new_with_mnemonic (_("_Refresh"));
+	gtk_box_pack_start (GTK_BOX (exo_gtk_dialog_get_action_area (GTK_DIALOG (dialog))), button, FALSE, TRUE, 0);
 	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (refresh_clicked), dialog);
 	gtk_widget_hide (button);
 
-	dialog->close = button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+	dialog->close = button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_CLOSE);
 	gtk_widget_show (button);
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 500, 400);
@@ -280,13 +286,10 @@ tsh_status_dialog_new (const gchar *title, GtkWindow *parent, GtkDialogFlags fla
 	if(flags & GTK_DIALOG_DESTROY_WITH_PARENT)
 		gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
 
-	if(flags & GTK_DIALOG_NO_SEPARATOR)
-		gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
-
 	return GTK_WIDGET(dialog);
 }
 
-void       
+void
 tsh_status_dialog_add (TshStatusDialog *dialog, const char *file, const char *text, const char *prop, const char *repo_text, const char *repo_prop)
 {
 	GtkTreeModel *model;
@@ -388,7 +391,7 @@ cancel_clicked (GtkButton *button, gpointer user_data)
 
 	gtk_widget_hide (dialog->cancel);
 	gtk_widget_show (dialog->refresh);
-	
+
   g_signal_emit (dialog, signals[SIGNAL_CANCEL], 0);
 }
 
@@ -431,4 +434,3 @@ move_info (GtkTreeStore *store, GtkTreeIter *dest, GtkTreeIter *src)
   g_free (repo_text);
   g_free (repo_prop);
 }
-
