@@ -84,10 +84,14 @@ static gpointer unlock_thread (gpointer user_data)
     svn_pool_destroy (subpool);
 
     error_str = tsh_strerror(err);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 		gdk_threads_enter();
     tsh_notify_dialog_add(dialog, _("Failed"), error_str, NULL);
 		tsh_notify_dialog_done (dialog);
 		gdk_threads_leave();
+G_GNUC_END_IGNORE_DEPRECATIONS
+
     g_free(error_str);
 
 		svn_error_clear(err);
@@ -97,10 +101,12 @@ static gpointer unlock_thread (gpointer user_data)
 
   svn_pool_destroy (subpool);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gdk_threads_enter();
 	tsh_notify_dialog_done (dialog);
 	gdk_threads_leave();
-	
+G_GNUC_END_IGNORE_DEPRECATIONS
+
   tsh_reset_cancel();
 	return GINT_TO_POINTER (TRUE);
 }
@@ -123,6 +129,6 @@ GThread *tsh_unlock (gchar **files, svn_client_ctx_t *ctx, apr_pool_t *pool)
 	args->dialog = TSH_NOTIFY_DIALOG (dialog);
 	args->files = files;
 
-	return g_thread_create (unlock_thread, args, TRUE, NULL);
+	return g_thread_new (NULL, unlock_thread, args);
 }
 
